@@ -2,7 +2,7 @@
 #
 # Part of the Rattle package for Data Mining
 #
-# Time-stamp: <2009-02-12 21:01:44 Graham Williams>
+# Time-stamp: <2009-10-25 20:51:42 Graham Williams>
 #
 # Copyright (c) 2009 Togaware Pty Ltd
 #
@@ -29,6 +29,7 @@ pmml.hclust <- function(model,
                         description="Hierarchical cluster model",
                         copyright=NULL,
                         transforms=NULL,
+                        dataset=NULL,
                         centers,
                         ...)
 {
@@ -45,8 +46,20 @@ pmml.hclust <- function(model,
   names(field$class) <- field$name
 
   orig.fields <- field$name
+
+  # 090822 Mark any categoric transforms as inactive since they won't
+  # have been used in the clustering (at least not until we automate
+  # the conversion to indicator variables.
+
+  for (i in which(sapply(transforms, function(x) x$type) %in%
+                  .TRANSFORMS.TO.CATEGORIC))
+    transforms[[i]]$status <- "inactive"
+  
   if (supportTransformExport(transforms))
-    field <- unifyTransforms(field, transforms)
+  {
+    field <- unifyTransforms(field, transforms, keep.first=FALSE)
+    transforms <- activateDependTransforms(transforms)
+  }
 
   number.of.clusters <- nrow(centers)
   cluster.names <- 1:number.of.clusters
